CREATE OR REPLACE VIEW amflux_merged_view AS
SELECT
amfluxeddy.timestamp_start,
amfluxeddy.timestamp_end,
amfluxeddy.co2,
amfluxeddy.co2_sigma,
amfluxeddy.h2o,
amfluxeddy.h2o_sigma,
amfluxeddy.fc,
amfluxeddy.fc_ssitc_test,
amfluxeddy.le,
amfluxeddy.le_ssitc_test,
amfluxeddy.et,
amfluxeddy.et_ssitc_test,
amfluxeddy.h,
amfluxeddy.h_ssitc_test,
amfluxeddy.g,
amfluxeddy.sg,
amfluxeddy.fetch_max,
amfluxeddy.fetch_90,
amfluxeddy.fetch_55,
amfluxeddy.fetch_40,
amfluxeddy.wd,
amfluxeddy.ws,
amfluxeddy.ws_max,
amfluxeddy.ustar,
amfluxeddy.zl,
amfluxeddy.tau,
amfluxeddy.tau_ssitc_test,
amfluxeddy.mo_length,
amfluxeddy.u,
amfluxeddy.u_sigma,
amfluxeddy.v,
amfluxeddy.v_sigma,
amfluxeddy.w,
amfluxeddy.w_sigma,
amfluxeddy.pa,
amfluxeddy.ta_1_1_1,
amfluxeddy.rh_1_1_1,
amfluxeddy.t_dp_1_1_1,
amfluxeddy.vpd,
amfluxeddy.t_sonic,
amfluxeddy.t_sonic_sigma,
amfluxeddy.alb,
amfluxeddy.netrad,
amfluxeddy.sw_in,
amfluxeddy.sw_out,
amfluxeddy.lw_in,
amfluxeddy.lw_out,
amfluxeddy.p,
amfluxeddy.ta_1_2_1,
amfluxeddy.rh_1_2_1,
amfluxeddy.t_dp_1_2_1,
amfluxeddy.ta_1_3_1,
amfluxeddy.rh_1_3_1,
amfluxeddy.t_dp_1_3_1,
amfluxeddy.ta_1_4_1,
amfluxeddy.pblh_f,
amfluxeddy.ch4,
amfluxeddy.fch4,
amfluxeddy.fch4_ssitc_test,
amfluxmet.alb as met_alb,
amfluxmet.netrad as met_netrad,
amfluxmet.sw_in as met_sw_in,
amfluxmet.sw_out as met_sw_out,
amfluxmet.lw_in as met_lw_in,
amfluxmet.lw_out as met_lw_out,
amfluxmet.t_canopy,
amfluxmet.t_si111_body,
amfluxmet.ppfd_in,
amfluxmet.vwc_1_1_1,
amfluxmet.ka_1_1_1,
amfluxmet.t_1_1_1,
amfluxmet.bulkec_1_1_1,
amfluxmet.vwc_1_2_1,
amfluxmet.ka_1_2_1,
amfluxmet.t_1_2_1,
amfluxmet.bulkec_1_2_1,
amfluxmet.vwc_1_3_1,
amfluxmet.ka_1_3_1,
amfluxmet.t_1_3_1,
amfluxmet.bulkec_1_3_1,
amfluxmet.vwc_1_4_1,
amfluxmet.ka_1_4_1,
amfluxmet.t_1_4_1,
amfluxmet.bulkec_1_4_1,
amfluxmet.vwc_1_5_1,
amfluxmet.ka_1_5_1,
amfluxmet.t_1_5_1,
amfluxmet.bulkec_1_5_1,
amfluxmet.vwc_1_6_1,
amfluxmet.ka_1_6_1,
amfluxmet.t_1_6_1,
amfluxmet.bulkec_1_6_1,
amfluxmet.vwc_1_7_1,
amfluxmet.ka_1_7_1,
amfluxmet.t_1_7_1,
amfluxmet.bulkec_1_7_1,
amfluxmet.vwc_1_8_1,
amfluxmet.ka_1_8_1,
amfluxmet.t__1_8_1,
amfluxmet.bulkec_1_8_1,
amfluxmet.vwc_1_9_1,
amfluxmet.ka_1_9_1,
amfluxmet.t_1_9_1,
amfluxmet.bulkec_1_9_1,
amfluxmet.ws as met_ws,
amfluxmet.wd as met_wd,
amfluxmet.lwmv_1_1_1,
amfluxmet.lwmdry_1_1_1,
amfluxmet.lwmcon_1_1_1,
amfluxmet.lwmwet_1_1_1,
amfluxmet.lwmv_1_1_2,
amfluxmet.lwmdry_1_1_2,
amfluxmet.lwmcon_1_1_2,
amfluxmet.lwmwet_1_1_2,
amfluxmet.ts_1_1_1,
amfluxmet.swc_1_1_1,
amfluxmet.lvl_ft,
amfluxmet.lvlout_ft,
amfluxmet.water_temp_c,
amfluxmet.vwc_2_1_1,
amfluxmet.ka_2_1_1,
amfluxmet.t_2_1_1,
amfluxmet.bulkec_2_1_1,
amfluxmet.vwc_2_2_1,
amfluxmet.ka_2_2_1,
amfluxmet.t_2_2_1,
amfluxmet.bulkec_2_2_1,
amfluxmet.vwc_2_3_1,
amfluxmet.t_2_3_1,
amfluxmet.bulkec_2_3_1,
amfluxmet.vwc_2_4_1,
amfluxmet.ka_2_4_1,
amfluxmet.t_2_4_1,
amfluxmet.bulkec_2_4_1,
amfluxmet.vwc_2_5_1,
amfluxmet.ka_2_5_1,
amfluxmet.t_2_5_1,
amfluxmet.bulkec_2_5_1,
amfluxmet.vwc_2_6_1,
amfluxmet.ka_2_6_1,
amfluxmet.t_2_6_1,
amfluxmet.bulkec_2_6_1,
amfluxmet.vwc_2_7_1,
amfluxmet.ka_2_7_1,
amfluxmet.t_2_7_1,
amfluxmet.bulkec_2_7_1,
amfluxmet.vwc_2_8_1,
amfluxmet.ka_2_8_1,
amfluxmet.t__2_8_1,
amfluxmet.bulkec_2_8_1,
amfluxmet.vwc_2_9_1,
amfluxmet.ka_2_9_1,
amfluxmet.t_2_9_1,
amfluxmet.bulkec_2_9_1
FROM amfluxeddy
FULL OUTER JOIN amfluxmet
USING (stationid, datetime_start);